.. fwdpy11 documentation master file, created by
   sphinx-quickstart on Mon Mar 20 12:22:19 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fwdpy11's documentation!
===================================

.. toctree::
    :caption: Contents:

.. toctree::
    :caption: Miscellaneous notes
    :maxdepth: 1

    misc/changelog
    misc/upgrade_path
    misc/deprecated
    misc/todo
    misc/pubs
    misc/developers

.. toctree::
    :caption: Concepts
    :maxdepth: 2

    pages/definitions

.. toctree::
    :caption: Introduction by way of example

    pages/0000a_anintroexample.rst

.. toctree::
    :caption: Objects and concepts

    pages/0000a_objectoverview.rst
    pages/mutation
    pages/recombination
    pages/softselection
    pages/demographydebugger
    pages/tsoverview
    pages/tstypes
    pages/tablefs.rst
    pages/0000a_tskit_interchange
    pages/recorders
    pages/tstimeseries
    pages/0000a_working_with_genotypes_trees.rst


.. toctree::
    :caption: Data types and functions
    :maxdepth: 2

    pages/types
    pages/genetic_values
    pages/gvalue_to_fitness
    pages/gvaluenoise
    pages/regiontypes
    pages/datamatrix
    pages/model_params
    pages/functions
    pages/demographic_models

.. toctree::
    :caption: References
    :maxdepth: 1

    misc/references

.. toctree::
    :caption: Examples

    examples/bgs
    examples/gss
    examples/snowdrift
    examples/recorder
    examples/migtest
    examples/localadaptation
    examples/IM
